==> chromium-58.0.3029.33.tar.xz: chromium-58.0.3029.33/chrome/browser/resources/md_bookmarks/list.js <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

Polymer({
  is: 'bookmarks-list',

  properties: {
    /** @type {BookmarkTreeNode} */
    menuItem_: Object,

    /** @type {Array<BookmarkTreeNode>} */
    displayedList: Array,

    searchTerm: String,
  },

  listeners: {
    'open-item-menu': 'onOpenItemMenu_',
  },

  /**
   * @param {Event} e
   * @private
   */
  onOpenItemMenu_: function(e) {
    this.menuItem_ = e.detail.item;
    var menu = /** @type {!CrActionMenuElement} */ (
        this.$.dropdown);
    menu.showAt(/** @type {!Element} */ (e.detail.target));
  },

  /** @private */
  onEditTap_: function() {
    this.closeDropdownMenu_();
    this.$.editBookmark.showModal();
  },

  /** @private */
  onCopyURLTap_: function() {
    var idList = [this.menuItem_.id];
    chrome.bookmarkManagerPrivate.copy(idList, function() {
      // TODO(jiaxi): Add toast later.
    });
    this.closeDropdownMenu_();
  },

  /** @private */
  onDeleteTap_: function() {
    if (this.menuItem_.url) {
      chrome.bookmarks.remove(this.menuItem_.id, function() {
        // TODO(jiaxi): Add toast later.
      }.bind(this));
    } else {
      chrome.bookmarks.removeTree(this.menuItem_.id, function() {
        // TODO(jiaxi): Add toast later.
      }.bind(this));
    }
    this.closeDropdownMenu_();
  },

  /** @private */
  onSaveEditTap_: function() {
    var edit = {'title': this.menuItem_.title};
    if (this.menuItem_.url)
      edit['url'] = this.menuItem_.url;

    chrome.bookmarks.update(this.menuItem_.id, edit);
    this.$.editBookmark.close();
  },

  /** @private */
  onCancelEditTap_: function() {
    this.$.editBookmark.cancel();
  },

  /** @private */
  closeDropdownMenu_: function() {
    var menu = /** @type {!CrActionMenuElement} */ (
        this.$.dropdown);
    menu.close();
  },

  /** @private */
  getEditActionLabel_: function() {
    var label = this.menuItem_.url ? 'menuEdit' : 'menuRename';
    return loadTimeData.getString(label);
  },

  /** @private */
  getEditorTitle_: function() {
    var title = this.menuItem_.url ? 'editBookmarkTitle' : 'renameFolderTitle';
    return loadTimeData.getString(title);
  },

  /** @private */
  emptyListMessage_: function() {
    var emptyListMessage = this.searchTerm ? 'noSearchResults' : 'emptyList';
    return loadTimeData.getString(emptyListMessage);
  },

  /** @private */
  isEmptyList_: function() {
    return this.displayedList.length == 0;
  },
});

==> chromium-59.0.3050.4.tar.xz: chromium-59.0.3050.4/chrome/browser/resources/md_bookmarks/list.js <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

Polymer({
  is: 'bookmarks-list',

  behaviors: [
    bookmarks.StoreClient,
  ],

  properties: {
    /** @type {BookmarkNode} */
    menuItem_: Object,

    /** @private {Array<string>} */
    displayedList_: {
      type: Array,
      value: function() {
        // Use an empty list during initialization so that the databinding to
        // hide #bookmarksCard takes effect.
        return [];
      },
    },

    /** @private */
    searchTerm_: String,
  },

  listeners: {
    'open-item-menu': 'onOpenItemMenu_',
  },

  attached: function() {
    this.watch('displayedList_', function(state) {
      return bookmarks.util.getDisplayedList(state);
    });
    this.watch('searchTerm_', function(state) {
      return state.search.term;
    });
    this.updateFromStore();
  },

  /**
   * @param {Event} e
   * @private
   */
  onOpenItemMenu_: function(e) {
    this.menuItem_ = e.detail.item;
    var menu = /** @type {!CrActionMenuElement} */ (
        this.$.dropdown);
    menu.showAt(/** @type {!Element} */ (e.detail.target));
  },

  /** @private */
  onEditTap_: function() {
    this.closeDropdownMenu_();
    /** @type {BookmarksEditDialogElement} */ (this.$.editDialog.get())
        .showEditDialog(this.menuItem_);
  },

  /** @private */
  onCopyURLTap_: function() {
    var idList = [this.menuItem_.id];
    chrome.bookmarkManagerPrivate.copy(idList, function() {
      // TODO(jiaxi): Add toast later.
    });
    this.closeDropdownMenu_();
  },

  /** @private */
  onDeleteTap_: function() {
    if (this.menuItem_.url) {
      chrome.bookmarks.remove(this.menuItem_.id, function() {
        // TODO(jiaxi): Add toast later.
      }.bind(this));
    } else {
      chrome.bookmarks.removeTree(this.menuItem_.id, function() {
        // TODO(jiaxi): Add toast later.
      }.bind(this));
    }
    this.closeDropdownMenu_();
  },

  /** @private */
  closeDropdownMenu_: function() {
    var menu = /** @type {!CrActionMenuElement} */ (
        this.$.dropdown);
    menu.close();
  },

  /** @private */
  getEditActionLabel_: function() {
    var label = this.menuItem_.url ? 'menuEdit' : 'menuRename';
    return loadTimeData.getString(label);
  },

  /** @private */
  emptyListMessage_: function() {
    var emptyListMessage = this.searchTerm_ ? 'noSearchResults' : 'emptyList';
    return loadTimeData.getString(emptyListMessage);
  },

  /** @private */
  isEmptyList_: function() {
    return this.displayedList_.length == 0;
  },
});
